@@ -9,96 +9,120 @@ class PioneerTV1: public PIRKeysetMetaData
 {
 public:
   PioneerTV1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class PioneerTV2: public PIRKeysetMetaData
 {
 public:
   PioneerTV2(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class PioneerTV3: public PIRKeysetMetaData
 {
 public:
   PioneerTV3(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class PioneerAudio1: public PIRKeysetMetaData
 {
 public:
   PioneerAudio1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class PioneerAudio1a: public PioneerAudio1
 {
 public:
   PioneerAudio1a(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class PioneerAudio2: public PIRKeysetMetaData
 {
 public:
   PioneerAudio2(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class PioneerAudio3: public PIRKeysetMetaData
 {
 public:
   PioneerAudio3(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class PioneerAudio4: public PIRKeysetMetaData
 {
 public:
   PioneerAudio4(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class PioneerAudio5: public PIRKeysetMetaData
 {
 public:
   PioneerAudio5(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class PioneerCD1: public PIRKeysetMetaData
 {
 public:
   PioneerCD1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class PioneerLaserDisc1: public PIRKeysetMetaData
 {
 public:
   PioneerLaserDisc1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class PioneerDVD1: public PIRKeysetMetaData
 {
 public:
   PioneerDVD1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 #endif // PIONEER_H
